@@ -28,6 +28,7 @@ class RelaxedMixin(PyCollector):
     """
     A mixin applying collection rules to both modules and inner/nested classes.
     """
+
     # TODO:
     # - worth calling super() in these? Difficult to know what to do with it;
     # it would say "no" to lots of stuff we want to say "yes" to.
@@ -153,14 +154,20 @@ class SpecInstance(RelaxedMixin, Instance):
                 setattr(obj, name, value)
         return obj
 
-    def makeitem(self, name, obj):
+    # Stub for pytest >=3.0,<3.3 where _makeitem did not exist
+    def makeitem(self, *args, **kwargs):
+        return self._makeitem(*args, **kwargs)
+
+    def _makeitem(self, name, obj):
         # More pytestmark skipping.
         if name == "pytestmark":
             return
         # NOTE: no need to modify collect() this time, just mutate item
-        # creation.
-        # TODO: can't we redo SpecClass the same way? And SpecModule??
-        item = super(SpecInstance, self).makeitem(name, obj)
+        # creation. TODO: but if collect() is still public, let's move to that
+        # sometime, if that'll work as well.
+        superb = super(SpecInstance, self)
+        attr = "_makeitem" if hasattr(superb, "_makeitem") else "makeitem"
+        item = getattr(superb, attr)(name, obj)
         # Replace any Class objects with SpecClass; this will automatically
         # recurse.
         # TODO: can we unify this with SpecModule's same bits?
